* Generic session options - page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=MAX formdlim=' ' spool; 									
* Kill default titles on output, ODS tables in log, turn on graphics; 
TITLE; ODS TRACE OFF; ODS LISTING; ODS GRAPHICS ON;

********************************************************************************
*******             BEGIN DATA MANIPULATION FOR EXAMPLE 10a              *******
*******             CHANGE "filesave" to your directory                  *******
********************************************************************************

* Location for original files for these models  change this path;
%LET filesave= C:\Dropbox\Example Data\Mabel Grammar Growth; 
LIBNAME filesave "&filesave.";

* Import data from SPSS;
LIBNAME growth SPSS "&filesave.\grw2grps.por";
DATA work.growthdata; SET growth.grw2grps; RUN;

* Create number of events for binomial model;
DATA work.growthdata; SET work.growthdata;
	wave=index1; Ntrials=100; PercentCorrect=CompTns;
	Ncorrect=ROUND(PercentCorrect*Ntrials,1); 
	IF class=2 THEN group="NLI";
	IF class=3 THEN group="SLI";
RUN;

* Send data to STATA;
PROC EXPORT DATA=work.growthdata OUTFILE="&filesave.\growthdata.dta" DBMS=STATA REPLACE; RUN;

********************************************************************************
******                    BEGIN EXAMPLE 10a MODELS						 *******
********************************************************************************

* Open output directory to save results to;
ODS RTF FILE="&filesave.\SAS_Example10a_Output.rtf" STYLE=HTMLBlue STARTPAGE=NO;

TITLE "Distribution of Percent Correct";
PROC UNIVARIATE NOPRINT DATA=work.growthdata; VAR PercentCorrect; 
	HISTOGRAM PercentCorrect / MIDPOINTS= 0 TO 1 BY .05 NORMAL(MU=EST SIGMA=EST); RUN; QUIT;
PROC MEANS DATA=work.growthdata; VAR PercentCorrect; RUN; TITLE;

TITLE "Empty Means Single-Level Model";
PROC GLIMMIX DATA=growthdata NOCLPRINT NOITPRINT METHOD=QUAD(QPOINTS=5) GRADIENT;
	CLASS ID group wave; 
	MODEL Ncorrect/Ntrials = / SOLUTION LINK=LOGIT DIST=BINOMIAL;
	ESTIMATE "Intercept" intercept 1 / ILINK; * ILINK un-logits prediction;
RUN;

TITLE "Empty Means Random Intercept Two-Level Model";
PROC GLIMMIX DATA=growthdata NOCLPRINT NOITPRINT METHOD=QUAD(QPOINTS=5) GRADIENT;
	CLASS ID group wave; 
	MODEL Ncorrect/Ntrials = / SOLUTION LINK=LOGIT DIST=BINOMIAL;
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN;
	ESTIMATE "Intercept" intercept 1 / ILINK; * ILINK un-logits prediction;
	COVTEST "Need Random Intercept?" 0;       * Test if random intercept is needed;
RUN;

TITLE "Saturated Means by Wave and Group Random Intercept Two-Level Model"; 
PROC GLIMMIX DATA=growthdata NOCLPRINT NOITPRINT METHOD=QUAD(QPOINTS=5) GRADIENT;
	CLASS ID group wave; 
	MODEL Ncorrect/Ntrials = wave|group / SOLUTION LINK=LOGIT DIST=BINOMIAL;
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN;
	LSMEANS wave*group / ILINK PLOT=MEANPLOT(SLICEBY=group JOIN);       * Plot in logts;
	LSMEANS wave*group / ILINK PLOT=MEANPLOT(SLICEBY=group JOIN ILINK); * Plot in prob;
	LSMEANS wave*group / DIFF=ALL;										* Pairwise diffs;
RUN;

* Close output;
ODS RTF CLOSE; 


